Function Get-FreeSpace {
Param(
[Parameter(Mandatory=$true, HelpMessage="Threshold Percentage")][int] $minimumThreshold,
[Parameter(Mandatory=$true, HelpMessage="Mark Mail as High Priority Percentage")][int] $HIGHPRIO,
[Parameter(Mandatory=$true, HelpMessage="Text File with Server List")][string] $ServerList,
[Parameter(Mandatory=$false, HelpMessage="Log to screen?")][boolean] $Logging,
[Parameter(Mandatory=$false, HelpMessage="Mail Log?")][boolean] $MailLog,
[Parameter(Mandatory=$false, HelpMessage="Mail recipient")][string] $Mailto,
[Parameter(Mandatory=$false, HelpMessage="Mail sender")][string] $From,
[Parameter(Mandatory=$false, HelpMessage="Mail Subject")][string] $Subject,
[Parameter(Mandatory=$false, HelpMessage="SMTP Server")][string] $Smtpserver,
[Parameter(Mandatory=$false, HelpMessage="List all CSV's")][boolean] $CompleteLog
)

##### [Parameter(Mandatory=$true, HelpMessage="Server to monitor")][array] $Servers, ##########
$datetime = Get-Date -Format "yyyyMMddHHmmss";

# Get server list
$servers = Get-Content $ServerList
$HighPrioFlag = "normal"
$SendMail = $false

if ($MailLog)
  {
  if ($Mailto -eq "") { $quit = $true }
  if ($From -eq "") { $quit = $true }
  if ($Subject -eq "") { $quit = $true }
  if ($Smtpserver -eq "") { $quit = $true }

  if ($quit) 
    { 
    write-host -f red "When using MailLog 'Mailto, From, Subject and Smtpserver' are required" 
  return 
    }
}
 
# Add headers to log file
#Add-Content "$Env:USERPROFILE\server disks $datetime.txt" "server,deviceID,size,freespace,percentFree";

$objs = @()
$FullTable = "<table><tr><td><b>Server</td><td><b>DeviceID</td><td><b>SizeGB</td><td><b>FreespaceGB</td><td><b>PercentFree</td></tr>"
$ThresholdTable = "<table><tr><td><b>Server</td><td><b>DeviceID</td><td><b>SizeGB</td><td><b>FreespaceGB</td><td><b>PercentFree</td></tr>"
 
foreach($server in $servers)
{
	# Get fixed drive info
	$disks = Get-WmiObject -ComputerName $server -Class Win32_LogicalDisk -Filter "DriveType = 3";
 
	foreach($disk in $disks)
	{
		
		$obj = New-Object PSObject
		
		$deviceID = $disk.DeviceID;
		[float]$size = $disk.Size;
		[float]$freespace = $disk.FreeSpace;

		$obj | add-member -membertype noteproperty -name Server -value $server -force
		$obj | add-member -membertype noteproperty -name Size -value $size -force
		$obj | add-member -membertype noteproperty -name DeviceID -value $DeviceID -force

		$percentFree = [Math]::Round(($freespace / $size) * 100, 2);
		$obj | add-member -membertype noteproperty -name PercentFree -value $percentFree -force

		$sizeGB = [Math]::Round($size / 1073741824, 2);
		$obj | add-member -membertype noteproperty -name sizeGB -value $sizeGB -force

		$freeSpaceGB = [Math]::Round($freespace / 1073741824, 2);
		$obj | add-member -membertype noteproperty -name FreespaceGB -value $freeSpaceGB -force

		if ($obj.PercentFree -le $HIGHPRIO)
			{
			$HighPrioFlag = "high"
			}
		
		$objs+=$obj
		
		if ($PercentFree -le $minimumThreshold)
			{
			$SendMail = $true
			$color = "#FF0000"
			$ThresholdTable += "<tr><td>" + $obj.Server + "</td><td>" + $obj.DeviceID + "</td><td>" + $obj.SizeGB + "</td><td>" + $obj.FreespaceGB + "</td><td><b><font color='$color'>" + $obj.PercentFree + "</font></b></td></tr>"
			}
		else
			{
			$color = "#00FF00"
			}
		$FullTable += "<tr><td>" + $obj.Server + "</td><td>" + $obj.DeviceID + "</td><td>" + $obj.SizeGB + "</td><td>" + $obj.FreespaceGB + "</td><td><b><font color='$color'>" + $obj.PercentFree + "</font></b></td></tr>"
		

	}

} 

$FullTable += "</table>"
$ThresholdTable += "</table>"
$objs = $objs | ft -auto Server,DeviceID,SizeGB,FreespaceGB,PercentFree

if ($Logging)
	{
	$objs
	}

if ($SendMail -OR $CompleteLog) {
if ($MailLog)
	{
	$body = "<b>Threshold Report:</b><br>" +$ThresholdTable


	if ($CompleteLog)
	{
	$body += "<p><b>Full Report:</b></p>" + $FullTable
	}
	#send-mailmessage -BodyAsHtml -body $FullTable -subject $Subject -to $mailto -from $From -smtpserver $Smtpserver -Priority $HighPrioFlag

	$subject = $subject + " less than " + $minimumThreshold + "%"
	send-mailmessage -BodyAsHtml -body $body -subject $Subject -to $mailto -from $From -smtpserver $Smtpserver -Priority $HighPrioFlag
	}
}

} #End Function Get-FreeSpace
